@@ -4,7 +4,7 @@
 #include <RcppArmadillo.h>
 #include <string>
 #include "mn.h"
-#include "templates.h"
+#include "Rfast.h"
 
 using namespace Rcpp;
 using namespace arma;
@@ -313,7 +313,7 @@ BEGIN_RCPP
     traits::input_parameter< const string >::type method(methodSEXP);
     traits::input_parameter< const bool >::type sqr(sqrSEXP);
     traits::input_parameter< const int >::type p(pSEXP);
-    __result = dist_vec(x,method,sqr,p);
+    __result = wrap(dist_vec(x,method,sqr,p));
     return __result;
 END_RCPP
 }
